@@ -68,8 +68,7 @@ BEGIN {
 		      reflog_cache_insert reflog_cache_lookup
                       $package_re $component_re $suite_re $deliberately_re
 		      $distro_re $versiontag_re $series_filename_re
-		      $orig_f_comp_re $orig_f_sig_re
-		      $tarball_f_ext_re $orig_f_tail_re
+		      $orig_f_comp_re $orig_f_sig_re $orig_f_tail_re
 		      $extra_orig_namepart_re
 		      $git_null_obj
                       $branchprefix
@@ -108,8 +107,7 @@ our $series_filename_re = qr{(?:^|\.)series(?!\n)$}s;
 our $extra_orig_namepart_re = qr{[-0-9a-zA-Z]+};
 our $orig_f_comp_re = qr{orig(?:-$extra_orig_namepart_re)?};
 our $orig_f_sig_re = '\\.(?:asc|gpg|pgp)';
-our $tarball_f_ext_re = "\\.tar(?:\\.\\w+)?(?:$orig_f_sig_re)?";
-our $orig_f_tail_re = "$orig_f_comp_re$tarball_f_ext_re";
+our $orig_f_tail_re = "$orig_f_comp_re\\.tar(?:\\.\\w+)?(?:$orig_f_sig_re)?";
 our $git_null_obj = '0' x 40;
 our $ffq_refprefix = 'ffq-prev';
 our $gdrlast_refprefix = 'debrebase-last';
@@ -634,15 +632,12 @@ sub git_check_unmodified () {
 sub upstream_commitish_search ($$) {
     my ($upstream_version, $tried) = @_;
     # todo: at some point maybe use git-deborig to do this
-    my @found;
     foreach my $tagpfx ('', 'v', 'upstream/') {
 	my $tag = $tagpfx.(dep14_version_mangle $upstream_version);
 	my $new_upstream = git_get_ref "refs/tags/$tag";
 	push @$tried, $tag;
-	push @found, [ $tag, $new_upstream ] if $new_upstream;
+	return $new_upstream if length $new_upstream;
     }
-    return @{ $found[0] } if @found == 1;
-    return ();
 }
 
 sub resolve_upstream_version ($$) {
@@ -652,8 +647,7 @@ sub resolve_upstream_version ($$) {
     my $message = __ 'using specified upstream commitish';
     if (!defined $new_upstream) {
 	my @tried;
-	($used, $new_upstream) =
-	    upstream_commitish_search $upstream_version, \@tried;
+	$new_upstream = upstream_commitish_search $upstream_version, \@tried;
 	if (!length $new_upstream) {
 	    fail f_
 		"Could not determine appropriate upstream commitish.\n".
@@ -661,6 +655,7 @@ sub resolve_upstream_version ($$) {
 		" Check version, and specify upstream commitish explicitly.",
 		"@tried";
 	}
+	$used = $tried[-1];
 	$message = f_ 'using upstream from git tag %s', $used;
     } elsif ($new_upstream =~ m{^refs/tags/($versiontag_re)$}s) {
 	$message = f_ 'using upstream from git tag %s', $1;
